@@ -1,7 +1,5 @@
 use core::ops::Add;
 
-use crate::Accidental;
-
 /// Music interval in semitones.
 #[derive(Clone, Copy, Debug, PartialEq, Eq, PartialOrd, Ord)]
 pub struct Interval {
@@ -25,9 +23,14 @@ impl Interval {
 
     pub const PERFECT_FIFTH: Self = Self::new(7);
 
+    pub const MINOR_SIXTH: Self = Self::new(8);
+    pub const MAJOR_SIXTH: Self = Self::new(9);
+
     pub const MINOR_SEVENTH: Self = Self::new(10);
     pub const MAJOR_SEVENTH: Self = Self::new(11);
 
+    pub const THIRTEENTH: Self = Self::new(21);
+
     pub const fn new(semitones: u8) -> Self {
         Self { semitones }
     }
@@ -37,9 +40,9 @@ impl Interval {
     }
 }
 
-impl From<Accidental> for Interval {
-    fn from(accidental: Accidental) -> Self {
-        accidental.interval()
+impl From<u8> for Interval {
+    fn from(semitones: u8) -> Self {
+        Self::new(semitones)
     }
 }
 
