@@ -10,7 +10,7 @@ impl Octave {
     /// Octave -1
     pub const NEGATIVE_ONE: Self = Self(-1);
     /// Octave 0
-    pub const ZERO: Self = Self(-1);
+    pub const ZERO: Self = Self(0);
     /// Octave 1
     pub const ONE: Self = Self(1);
     /// Octave 2
@@ -28,6 +28,10 @@ impl Octave {
     /// Octave 8
     pub const EIGHT: Self = Self(8);
 
+    pub fn new_unchecked(num: i8) -> Self {
+        Self(num)
+    }
+
     /// Return the `Octave` of the given midinote.
     pub const fn from_midi(note: MidiNote) -> Self {
         Self((note.into_byte() / (Pitch::B.into_byte() + 1)) as i8 - 1)
